# eric7.Sessions.SessionFile

Module implementing a class representing the session JSON file.

### Global Attributes

None

### Classes

SessionFile | Class representing the session JSON file.

### Functions

None

## SessionFile

Class representing the session JSON file.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

SessionFile | Constructor
readFile | Public method to read the session data from a session JSON file.
writeFile | Public method to write the session data to a session JSON file.

### Static Methods

None

#### SessionFile (Constructor)

SessionFile(isGlobal: bool, parent: QObject = None)

Constructor

isGlobal (bool)
  flag indicating a file for a global session
parent (QObject (optional))
  reference to the parent object (defaults to None)

#### SessionFile.readFile

readFile(filename: str)

Public method to read the session data from a session JSON file.

filename (str)
  name of the project file

Return:
  flag indicating a successful read

Return Type:
  bool

#### SessionFile.writeFile

writeFile(filename: str, withServer: bool = True)

Public method to write the session data to a session JSON file.

filename (str)
  name of the session file
withServer (bool (optional))
  flag indicating to save the current server connection (defaults to True)

Return:
  flag indicating a successful write

Return Type:
  bool

Up